cf

package
v0.0.0-...-6d4ca3b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 24, 2019 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateCloudformationParameters

func CreateCloudformationParameters(parameterMap map[string]string) []*cloudformation.Parameter

CreateCloudformationParameters is a method to convert a map of parameter key value pairs into AWS Parameters

func GetOutputValue

func GetOutputValue(stack cloudformation.Stack, key string) string

GetOutputValue method will retrieve an output value from Output array

Types

type AWSElb

type AWSElb struct {
	Client elbv2iface.ELBV2API
}

AWSElb is a struct to interact with ELBV2 API

func (AWSElb) GetHighestPriority

func (lb AWSElb) GetHighestPriority(listenerArn *string) (int, error)

GetHighestPriority is a method to retrieve highest priority for ELBV2 Listener Rules

type CFExecutor

type CFExecutor struct {
	Client cloudformationiface.CloudFormationAPI
}

CFExecutor struct used to create cloudformation stacks

func (CFExecutor) CreateStack

func (executor CFExecutor) CreateStack(templateBody string, stackName string, parameters []*cloudformation.Parameter) error

CreateStack is a general method to create aws cloudformation stacks

func (CFExecutor) PauseUntilCreateFinished

func (executor CFExecutor) PauseUntilCreateFinished(stackName string) error

PauseUntilCreateFinished is a method to wait on the status of a cloudformation stack until it finishes

func (CFExecutor) PauseUntilUpdateFinished

func (executor CFExecutor) PauseUntilUpdateFinished(stackName string) error

PauseUntilUpdateFinished is a method to wait on the status of a cloudformation stack until it finishes

func (CFExecutor) UpdateStack

func (executor CFExecutor) UpdateStack(templateBody string, stackName string, parameters []*cloudformation.Parameter) error

UpdateStack is a method to update Cloudformation stack

type Executor

type Executor interface {
	CreateStack(templateBody string, stackName string, parameters []*cloudformation.Parameter) error
	UpdateStack(templateBody string, stackName string, parameters []*cloudformation.Parameter) error

	PauseUntilCreateFinished(stackName string) error
	PauseUntilUpdateFinished(stackName string) error
}

Executor is an interface to execute and create stacks

type LoadBalancer

type LoadBalancer interface {
	GetHighestPriority(listenerArn *string) (int, error)
}

LoadBalancer is an interface to define services

type Resource

type Resource interface {
	GetStack(stackName *string) (cloudformation.Stack, error)
}

Resource is a generic interface for retrieving information on a infrastruture stack

type Stack

type Stack struct {
	Client cloudformationiface.CloudFormationAPI
}

Stack is a struct representing an AWS Cloudformation Stack

func (Stack) GetStack

func (stack Stack) GetStack(stackName *string) (cloudformation.Stack, error)

GetStack is a method to retrieve an AWS stack by stack name

Jump to